@@ -11,8 +11,9 @@ from hydenv.examples.gpx import HydenvGPXExample
 from hydenv.examples.raspi_logger import HydenvRaspiLoggerExample
 from hydenv.examples.owm import HydenvOWMExample
 from hydenv.examples.netatmo import HydenvNetatmoExample
+from hydenv.examples.camels_de import HydenvCamelsDeExample
 
-CLIs = [HydenvHoboExamples, HydenvSpaceExamples, HydenvOSMExamples, HydenvEarthquakeExamples, HydenvWorldBorderExample, HydenvGPXExample, HydenvRaspiLoggerExample, HydenvOWMExample, HydenvNetatmoExample]
+CLIs = [HydenvHoboExamples, HydenvSpaceExamples, HydenvOSMExamples, HydenvEarthquakeExamples, HydenvWorldBorderExample, HydenvGPXExample, HydenvRaspiLoggerExample, HydenvOWMExample, HydenvNetatmoExample, HydenvCamelsDeExample]
 
 class HydenvExamples:
     r"""
@@ -30,7 +31,7 @@ class HydenvExamples:
         self.__connection = connection
         self.quiet = quiet
 
-    def hobo(self, terms='all', only=None, data_path='download'):
+    def hobo(self, terms='all', only=None, data_path='download', metadata_source='google'):
         """
         Import HOBO data.\n
         This high level script downloads all neccessary resources for the HOBO 
@@ -41,7 +42,7 @@ class HydenvExamples:
         :param data_path: Either 'download' (default) or a local path to the data
         :param only: If set, only the given entities will be uploaded.
         """
-        cli = HydenvHoboExamples(connection=self.__connection)
+        cli = HydenvHoboExamples(connection=self.__connection, metadata_source=metadata_source)
         return cli.run(terms=terms, data_path=data_path, only=only, quiet=self.quiet)
 
     def space(self, normalize=False):
@@ -119,9 +120,9 @@ class HydenvExamples:
         """
         Import OpenWeatherMap example data.\n
         This high level script downloads data from the OpenWeatherMap database and 
-        exports the data to the given save path. Currently, the direct upload to the 
-        database is not yet supported.
-        :param save: The path to save the data to.
+        exports the data to the given save path. If you do not specify a save path (default),
+        the data will be uploaded to the database.
+        :param save: The path to save the data to. If empty, the data will be loaded to the database
         :param fmt: The format of the data. Currently, only json and csv is supported.
         :param variable: The variable to download. Defaults temperature and humidity.
         :param if_exists: Specifies the action if the data already exists. Can be 'replace', 'raise' or 'ignore'.
@@ -231,6 +232,31 @@ class HydenvExamples:
         if not self.quiet:
             print('All done.')
     
+    def camels_de(self, source_dir: str = None, nuts_filter: str = None, only: str = None, drop: bool = False):
+        """
+        CAMELS-DE example.\n
+        Loads the CAMELS-DE dataset to the database. Currently, only the state API is used,
+        as the CAMELS-DE dataset is not yet published. If you want to add data along with
+        the metadata (through state API), you need a local copy of the data and set the
+        source_dir parameter.
+        :param source_dir: string - Path to the CAMELS-DE output_data directory
+        :param nuts_filter: string - Filter by federal state using the NUTS level 2 id, like DE1, DE2 ... DEG
+        :param only: string - If set, upload only 'metadata' or 'data'
+        :param drop: bool - If set, all other parameters are ignored and the CAMELS-DE data is dropped. 
+        """
+        # initialize the CLI
+        cli = HydenvCamelsDeExample(self.__connection, source_dir=source_dir, quiet=self.quiet)
+        
+        # first check if the tables should be dropped
+        if drop:
+            if not self.quiet:
+                print('Cleaning CAMELS-DE tables...', end='')
+            cli.drop() 
+            if not self.quiet:
+                print('done.')
+        else:
+            # otherwise run the CLI
+            cli.run(only=only, nuts_filter=nuts_filter)
 
     def clean(self): 
         """
